# TestPointByTestSuiteModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**tester_id** | **str, none_type** |  | [optional] 
**work_item_id** | **str, none_type** |  | [optional] 
**configuration_id** | **str, none_type** |  | [optional] 
**status** | **str, none_type** | Applies one of these values: Blocked, NoResults, Failed, Passed | [optional] 
**last_test_result_id** | **str, none_type** |  | [optional] 
**iteration_id** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


